``eradiate.data``
=================

.. automodule:: eradiate.data

.. py:currentmodule:: eradiate.data

Functions
---------

.. autosummary::
   :toctree: generated/autosummary/

   init_data_store
   open_dataset
   load_dataset

Classes
-------

.. autosummary::
   :toctree: generated/autosummary/

   DataStore
   BlindDirectoryDataStore
   BlindOnlineDataStore
   SafeDirectoryDataStore
   SafeOnlineDataStore
   MultiDataStore

Attributes
----------

.. data:: data_store

   Global data store. Alias to :data:`eradiate.data._store.data_store`.
   See also: :class:`eradiate.data.MultiDataStore`.
